function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component, Fragment } from 'react';
import PropTypes from 'prop-types';
import { withStyles } from 'material-ui/styles';

import Toolbar from 'material-ui/Toolbar';
import Typography from 'material-ui/Typography';
import IconButton from 'material-ui/IconButton';
import Tooltip from 'material-ui/Tooltip';
import DeleteIcon from 'material-ui-icons/Delete';
// import FilterListIcon from 'material-ui-icons/FilterList';
import AddIcon from 'material-ui-icons/AddCircleOutline';

import { lighten } from 'material-ui/styles/colorManipulator';
import Grid from 'material-ui/Grid';

import ChoseColumns from "./ChoseColumns";
import ExportToExcel from "./ExportToExcel";

var toolbarStyles = function toolbarStyles(theme) {
  return {
    root: {
      paddingRight: theme.spacing.unit,
      alignItems: "flex-end"
    },
    highlight: theme.palette.type === 'light' ? {
      color: theme.palette.secondary.dark,
      backgroundColor: lighten(theme.palette.secondary.light, 0.4)
    } : {
      color: lighten(theme.palette.secondary.light, 0.4),
      backgroundColor: theme.palette.secondary.dark
    },
    spacer: {
      flex: '1 1 100%'
    },
    actions: {
      color: theme.palette.text.secondary,
      display: "flex"
    },
    title: {
      flex: '0 0 auto'
    }
  };
};

export var EnhancedTableToolbar = function (_Component) {
  _inherits(EnhancedTableToolbar, _Component);

  function EnhancedTableToolbar() {
    _classCallCheck(this, EnhancedTableToolbar);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  EnhancedTableToolbar.prototype.render = function render() {
    var _props = this.props,
        numSelected = _props.numSelected,
        classes = _props.classes,
        title = _props.title,
        addObject = _props.addObject,
        filters = _props.filters,
        columnData = _props.columnData,
        toggleColumnVisibility = _props.toggleColumnVisibility,
        exportable = _props.exportable,
        table = _props.table;


    var columns = [];

    if (title) {
      columns.push(React.createElement(
        Grid,
        {
          key: 'title',
          item: true
        },
        React.createElement(
          Typography,
          { type: 'title' },
          title
        )
      ));
    }

    if (filters) {
      columns.push(React.createElement(
        Grid,
        {
          key: 'filters',
          item: true,
          xs: true
        },
        filters
      ));
    } else {
      columns.push(React.createElement(
        Grid,
        {
          key: 'separator',
          item: true,
          xs: true
        },
        null
      ));
    }

    if (exportable) {
      columns.push(React.createElement(
        Grid,
        {
          key: 'ExportToExcel',
          item: true
        },
        React.createElement(ExportToExcel, {
          columnData: columnData,
          table: table
        })
      ));
    }

    if (columnData && columnData.length) {
      columns.push(React.createElement(
        Grid,
        {
          key: 'ChoseColumns',
          item: true
        },
        React.createElement(ChoseColumns, {
          columnData: columnData,
          toggleColumnVisibility: toggleColumnVisibility
        })
      ));
    }

    if (addObject) {
      var _global = global,
          document = _global.document;

      var _ref = document || {},
          createRange = _ref.createRange;

      if (createRange) {

        /**
         * https://github.com/jsdom/jsdom/issues/317
         */

        columns.push(React.createElement(
          Grid,
          {
            key: 'add',
            item: true
          },
          React.createElement(
            Tooltip,
            { title: '\u0414\u043E\u0431\u0430\u0432\u0438\u0442\u044C' },
            React.createElement(
              IconButton,
              {
                'aria-label': 'AddPlace',
                onClick: addObject
              },
              React.createElement(AddIcon, null)
            )
          )
        ));
      }
    }

    return React.createElement(
      Toolbar,
      {
        className: [classes.root, numSelected > 0 ? classes.highlight : null].join(" ")
      },
      React.createElement(
        Grid,
        {
          container: true,
          alignItems: 'center'
        },
        columns
      )
    );
  };

  return EnhancedTableToolbar;
}(Component);

EnhancedTableToolbar.propTypes = process.env.NODE_ENV !== "production" ? {
  classes: PropTypes.object.isRequired,
  numSelected: PropTypes.number.isRequired,
  title: PropTypes.string.isRequired,
  addObject: PropTypes.func,
  columnData: PropTypes.array.isRequired,
  toggleColumnVisibility: PropTypes.func.isRequired,
  exportable: PropTypes.bool.isRequired,
  table: PropTypes.instanceOf(HTMLTableElement).isRequired
} : {};
export default withStyles(toolbarStyles)(function (props) {
  return React.createElement(EnhancedTableToolbar, props);
});